@@ -550,6 +550,27 @@ class CMSOrders {
 		return $order_id;			
 	}
 
+	function GenerateUserPassword ($length = 8) {
+		// Script taken from Jon Haworth
+		// Start with a blank password
+		$password = '';
+		// Define possible characters
+		$possible = "0123456789bcdfghjkmnpqrstvwxyz"; 
+		// Set up a counter
+		$i = 0; 
+		// Add random characters to $password until $length is reached
+		while ($i < $length) { 
+			// Pick a random character from the possible ones
+			$char = substr($possible, mt_rand(0, strlen($possible)-1), 1);
+			// We don't want this character if it's already in the password
+			if (!strstr($password, $char)) { 
+			  $password .= $char;
+			  $i++;
+			}
+		}
+		return $password;
+	}
+
 	function SendCustomerConfirmationMail($orderheader) {
 		$db = cmsms()->GetDb();
 		// Retrieve the password of the customer so we can check if this is a brand new customer
